<?php
/**
 * @file
 * A basic microsites extension
 */

/**
 * The basic microsite extension holds basic instantiation and
 * housekeeping methods.
 */
class BasicMicrositesExtension {

  /**
   * Microsite configuration
   */
  public $microsite;

  /**
   * Configuration for this plugin
   */
  public $config;

  /**
   * Constructor
   *
   * @param $config
   * @param Microsite $microsite
   */
  public function __construct($config, $microsite) {
    $this->config = $config;
    $this->microsite = $microsite;
  }

  /**
   * Requirements
   */
  public function requirements() {
    return TRUE;
  }

  /**
   * Trigger on Enable
   */
  public function enable() {
    // Do nothing
  }

  /**
   * Reset
   */
  public function reset() {
    // Do nothing
  }

  /**
   * Run on a given page load when the microsite is active
   */
  public function active() {
    // Do nothing
  }

  /**
   * Trigger on Disable
   */
  public function disable() {
    // Do nothing
  }

  /**
   * Trigger on Disable
   */
  public function delete() {
    // Do nothing
  }

  /**
   * Configuration form
   *
   * @param $form
   *
   * @return bool
   */
  public function configForm(&$form) {
    // Do nothing
  }

  /**
   * Save the results of the configuration form
   *
   * @param $form
   * @param $form_state
   *
   * @return bool
   */
//  public function configFormSave(&$form, $form_state) {
//    // Do nothing
//  }

  /**
   * Save settings for this plugin
   *
   * This can be implemented by plugins to save data safely, and have it
   * available again on load. Remember to sanitize user input.
   *
   * @param $key
   *  The key to save data
   * @param $value
   *  They value to save
   */
  public function saveSetting($key, $value) {
    if (!isset($this->microsite->data[$this->config['name']])) {
      $this->microsite->data[$this->config['name']] = array();
    }
    $this->microsite->data[$this->config['name']][$key] = $value;
  }

  /**
   * Save settings for this plugin
   *
   * Retrieve a setting saved via saveSetting(), above.
   *
   * @param $key
   *  The key to return data for
   * @param null $plugin
   *  Optionally, the plugin which sourced the setting (if not the current plugin)
   *  This allows plugins to access data saved by others.
   *
   * @return mixed
   */
  public function getSetting($key, $plugin = NULL) {
    if (!isset($plugin) || empty($plugin)) {
      $plugin = $this->config['name'];
    }

    if (isset($this->microsite->data[$plugin]) && isset($this->microsite->data[$plugin][$key])) {
      return $this->microsite->data[$plugin][$key];
    }
    return FALSE;
  }

  /**
   * Generate a unique name
   */
  public function name() {
    return 'microsite_' . str_replace('-', '_', $this->microsite->name);
  }
}
