<?php
/**
 * @file
 * API information for Microsites
 */

/**
 * Alter microsite Contexts before creation
 *
 * Allows implementers to alter the Context before it is instantiated. This is
 * useful if you want to set properties across a set of microsites, rather
 * than configuring each one independently.
 *
 * @param $context
 *  The context to set
 * @param $microsite
 *  The microsite configuration (not alterable)
 */
function hook_microsites_context_alter(&$context, $microsite) {
  // Example:
  // Set the context tag based on the node type of the microsite
  if ($microsite->type == 'my_node_type') {
    $context->tag = 'my_node_type';
  }
}

/**
 * Alter microsite objects before they are returned
 *
 * This hook gives implementers the opportunity to alter the microsite object
 * before it is used by the Microsite framework
 *
 * @param \Microsite $microsite
 *  An object of type Microsite
 */
function hook_microsites_microsite_alter(&$microsite) {
  // Example:
  // Add additional information to the Microsite::data array
  $microsite->data['my_key'] = 'foo';
}
