<?php
/**
 * A basic microsites extension
 */

$plugin = array(
  'title' => t('Context'),
  'description' => t('Trigger contexts based on Microsites.'),
  'class' => array(
    'class' => 'ContextMicrositesExtension'
  ),
  'weight' => -5
);

/**
 * Adds Context support for Microsites
 */
class ContextMicrositesExtension extends BasicMicrositesExtension {

  /**
   * Implements requirements()
   */
  public function requirements() {
    if (module_exists('context')) {
      return TRUE;
    }
    return FALSE;
  }

  /**
   * Implements enable()
   */
  public function enable() {
    // Enable the microsite
    $context = context_load($this->name());
    if(is_object($context)) {
      xu('ctools');
      xu_ctools_export_ui_enable($context, 'context');

      context_invalidate_cache();
    }
    else {
      $this->reset();
    }
  }

  /**
   * Implements reset()
   */
  public function reset() {
    $context = $this->defineContext();
    context_save($context);
    $this->saveSetting('name', $context->name);

    xu('ctools');
    xu_ctools_export_ui_enable($context, 'context');

    context_invalidate_cache();
  }

  /**
   * Implements disable()
   */
  public function disable() {
    // Disable the context
    if($context = context_load($this->name())) {
      xu('ctools');
      xu_ctools_export_ui_disable($context, 'context');

      context_invalidate_cache();
    }
  }

  /**
   * Implements delete()
   */
  public function delete() {
    if($context = context_load($this->name())) {
      context_delete($context);
    }
  }

  /**
   * Create a context definition
   *
   * @return stdClass
   *  A context definition for this microsite, for use with context_save()
   */
  protected function defineContext() {
    if (!isset($this->microsite->nid)) {
      return FALSE;
    }
    if (!isset($this->microsite->node) && isset($this->microsite->nid)) {
      $this->microsite->nodeLoad($this->microsite->nid);
    }

    // Get the base path for this microsite from basic settings
    $base_path = $this->getSetting('base_path', 'default');

    // Prepare a default Context definition
    $context = new stdClass;
    $context->disabled = FALSE; /* Edit this to TRUE to make a default context disabled initially */
    $context->api_version = 3;
    $context->name = $this->name();
    $context->description = 'Dynamically generated context for ' . $this->microsite->name;
    $context->tag = 'microsite';
    $context->conditions = array(
      'path' => array(
        'values' => array(
          $base_path => $base_path,
          $base_path .'/*' => $base_path .'/*',
        ),
      ),
    );
    $context->reactions = array(
      'block' => array(
        'blocks' => array(
          $this->name() => array(
            'module' => 'menu',
            'delta' => $this->getSetting('menu_name', 'menu'),
            'region' => 'left',
            'weight' => 0,
          ),
        ),
      ),
      'theme' => array(
        'title' => $this->getSetting('title', 'default'),
        'subtitle' => '',
        'class' => 'microsite '. $this->name(),
      ),
      // This last bit triggers some Microsites behaviour. Don't override it
      // unless you know what you are doing.
      'microsites' => array(
        'active' => 1,
        'site' => $this->microsite->name,
      ),
    );
    $context->condition_mode = 0;

    // Allow implementers to alter this Context before saving
    drupal_alter('microsites_context', $context, $this);

    // Translatables
    // Included for use with string extractors like potx.
    t('Dynamically generated context for');
    t('microsite');

    return $context;
  }
}
