<?php
/**
 * @file
 * Menu settings by content type compatibility
 */

$plugin = array (
  'title' => t('Menu settings by content type'),
  'description' => t('Ensures menus created by the Menu extension are available to all content types on creation.'),
  'class' => array(
    'class' => 'CtmMicrositesExtension',
  ),
);

/**
 * The basic microsite extension holds basic instantiation and
 * housekeeping methods.
 */
class CtmMicrositesExtension extends BasicMicrositesExtension {

  /**
   * Store CTM settings
   */
  private $ctmSettings = array();

  /**
   * Implements requirements()
   */
  public function requirements() {
    if (module_exists('ctm')) {
      return TRUE;
    }
    return FALSE;
  }

  /**
   * Trigger on Enable
   */
  public function enable() {
    if ($this->getSetting('ctm_updated') != TRUE) {
      $this->reset();
      $this->saveSetting('ctm_updated', TRUE);
    }
  }

  /**
   * Reset
   */
  public function reset() {
    $this->getCtmSettings();
    $this->addMenutoCtm();
  }

  /**
   * Run on a given page load when the microsite is active
   */
  public function active() {
    // Do nothing
  }

  /**
   * Trigger on Disable
   */
  public function disable() {
    // Do nothing
  }

  /**
   * Trigger on Disable
   */
  public function delete() {
    $this->getCtmSettings();
    $this->removeFromCtm();
  }

  /**
   * Load all CTM variables
   */
  private function getCtmSettings() {
    $result = db_query("SELECT * FROM {variable} WHERE `name` LIKE '%_menu_settings%'");
    while($setting = db_fetch_array($result)) {
      $this->ctmSettings[$setting['name']] = unserialize($setting['value']);
    }
  }

  /**
   * Add the menu for this item to all types
   */
  private function addMenuToCtm() {
    $menu_name = $this->getSetting('menu_name', 'menu');
    foreach($this->ctmSettings as $key => $setting) {
      $setting[$menu_name] = $menu_name;
      variable_set($key, $setting);
    }
  }

  /**
   * Add the menu for this item to all types
   */
  private function removeFromCtm() {
    $menu_name = $this->getSetting('menu_name', 'menu');
    foreach($this->ctmSettings as $key => $setting) {
      if (isset($setting[$menu_name])) {
        unset($setting[$menu_name]);
        variable_set($key, $setting);
      }
    }
  }
}
