<?php
/**
 * A basic microsites extension
 */

$plugin = array(
  'title' => t('Menu'),
  'description' => t('Provides menu management for microsites.'),
  'class' => array(
    'class' => 'MenuMicrositesExtension',
  ),
  '#weight' => -8
);

/**
 * Basic menu support
 */
class MenuMicrositesExtension extends BasicMicrositesExtension {

  /**
   * Implements requirements()
   */
  public function requirements() {
    if (module_exists('custom_menu')) {
      return TRUE;
    }
    return FALSE;
  }

  /**
   * Implements enable()
   */
  public function enable() {
    $this->createMenu();
  }

  /**
   * Implements reset()
   */
  public function reset() {
    $this->deleteMenu();
    $this->createMenu();
  }

  /**
   * Implements disable()
   */
  public function disable() {
    // Do nothing, we remove menus only on delete, and we let Context take care
    // of the rest.
  }

  /**
   * Implements delete()
   */
  public function delete() {
    $this->deleteMenu();
  }

  /**
   * Initialise a menu
   *
   * @return bool|\Microsite
   *  Either FALSE, if the node is not set, or $this
   */
  protected function createMenu() {
    $this->saveSetting('menu_name', 'microsite-' . str_replace('_', '-', $this->microsite->name));

    if (!isset($this->microsite->node) && !isset($this->microsite->node->nid)) {
      return FALSE;
    }
    $key = microsites_make_key($this->microsite->node);
    $router_item = menu_get_item('node/' . $this->microsite->node->nid);

    // Create the custom menu for this microsite
    $custom_menu = custom_menu_exists($this->menuName());
    if (empty($custom_menu)) {
      $menu = array(
        'menu_name' => $this->menuName(),
        'description' => 'Dynamic menu for Microsite. This menu can only be changed by turning the microsite setting for the corresponding node off.',
        'title' => 'Microsite: ' . $this->microsite->node->title,
      );
      custom_menu_save($menu);
    }

    // Add a home link for this node
    if (empty($router_item) || $router_item['menu_name'] != $this->menuName()) {
      $router_item = array(
        'link_path' => drupal_get_normal_path($this->microsite->node->path),
        'link_title' => $this->getSetting('title', 'default'),
        'menu_name' => $this->menuName(),
        'router_item' => 'node/%'
      );
      $menu_save = menu_link_save($router_item);
      $this->saveSetting('mlid', $menu_save);
    }

    return $this;
  }

  /**
   * Remove the default menu item
   */
  protected function deleteMenu() {
    $mlid = $this->getSetting('mlid');
    if (!empty($mlid)) {
      menu_link_delete($mlid, NULL);
    }
    custom_menu_delete($this->menuName());
  }

  /**
   * Generate a unique name
   *
   * Menu names dont use underscores, so we have to replace them for this plugin
   */
  public function menuName() {
    return $this->getSetting('menu_name');
  }
}
