<?php
/**
 * A basic microsites extension
 */

$plugin = array(
  'title' => t('Menu block'),
  'description' => t('Create menu block blocks for microsites.'),
  'class' => array(
    'class' => 'MenuBlockMicrositesExtension'
  ),
  'weight' => -7
);

/**
 * Adds Menu Block
 */
class MenuBlockMicrositesExtension extends BasicMicrositesExtension {

  /**
   * Implements requirements()
   */
  public function requirements() {
    if (module_exists('menu_block')) {
      return TRUE;
    }
    return FALSE;
  }

  /**
   * Implements enable()
   */
  public function enable() {
    $this->reset();
  }

  /**
   * Implements active()
   */

  /**
   * Implements reset()
   */
  public function reset() {
    $config = $this->menuBlockConfig();
    $this->saveMenuBlock($config);
  }

  /**
   * Implements disable()
   */
  public function disable() {

  }

  /**
   * Implements delete()
   */
  public function delete() {
    $this->deleteMenuBlock();
  }

  /**
   * Generate a configuration for Menu Block
   */
  protected function menuBlockConfig() {
    $result = db_query('SELECT rid, name FROM {role} ORDER BY name');
    $role_options = array();
    while ($role = db_fetch_object($result)) {
      $role_options[$role->rid] = 0;
    }

    $config = array(
      'visibility' => '',
      'pages' => '',
      'custom' => '',
      'title' => '<none>',
      'module' => 'menu_block',
      'roles' => $role_options,
      'title_link' => 0,
      'admin_title' => 'Microsites: '. $this->name(),
      'level' => '1',
      'follow' => '0',
      'follow_parent' => 'active',
      'depth' => '1',
      'expanded' => 0,
      'sort' => 0,
      'parent_mlid' => $this->getSetting('menu_name', 'menu') .':0',
      'parent' => $this->getSetting('menu_name', 'menu') .':0',
    );

    drupal_alter('microsites_menu_block_config', $config, $this);

    return $config;
  }

  /**
   * Save a menu block
   */
  protected function saveMenuBlock($config) {
    $block_ids = variable_get('menu_block_ids', array());
    $delta = empty($block_ids) ? 1 : max($block_ids) + 1;

    // Store the delta
    $this->saveSetting('delta', $delta);

    // Save the new array of blocks IDs.
    $block_ids[] = $delta;
    variable_set('menu_block_ids', $block_ids);

    // Save the block configuration.
    module_load_include('inc', 'menu_block', 'menu_block.admin');
    _menu_block_block_save($delta, $config);

    xu('block');
    xu_block_save($delta, $config);
  }

  /**
   * Delete a menu block
   */
  protected function deleteMenuBlock() {
    $delta = $this->getSetting('delta');

    $block_ids = variable_get('menu_block_ids', array());
    unset($block_ids[array_search($delta, $block_ids)]);
    sort($block_ids);
    variable_set('menu_block_ids', $block_ids);
    variable_del("menu_block_{$delta}_title_link");
    variable_del("menu_block_{$delta}_admin_title");
    variable_del("menu_block_{$delta}_parent");
    variable_del("menu_block_{$delta}_level");
    variable_del("menu_block_{$delta}_follow");
    variable_del("menu_block_{$delta}_depth");
    variable_del("menu_block_{$delta}_expanded");
    variable_del("menu_block_{$delta}_sort");

    xu('block');
    xu_block_delete($delta, 'menu_block');
  }
}
